changeset 4205:b56fa3e45dba HEAD

If dbox mail is lost, synchronize the dbox instead of just refreshing index (it's not enough).
author Timo Sirainen <timo.sirainen@movial.fi>
date Thu, 20 Apr 2006 17:15:58 +0300
parents 9c8a79d36bb0
children ec7e56827ea8
files src/lib-storage/index/dbox/dbox-mail.c
diffstat 1 files changed, 2 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/src/lib-storage/index/dbox/dbox-mail.c	Thu Apr 20 17:10:11 2006 +0300
+++ b/src/lib-storage/index/dbox/dbox-mail.c	Thu Apr 20 17:15:58 2006 +0300
@@ -105,12 +105,10 @@
 			break;
 		}
 
 		/* mail was moved. resync index file to find out the new offset
 		   and try again. */
-		if (mail_index_refresh(mbox->ibox.index) < 0) {
-			mail_storage_set_index_error(&mbox->ibox);
+		if (dbox_sync(mbox, FALSE) < 0)
 			return -1;
-		}
 		prev_file_seq = file_seq;
 		prev_offset = offset;
 	}
@@ -105,12 +105,10 @@
 		}
 
-		/* mail was moved. resync index file to find out the new offset
+		/* mail was moved. resync dbox to find out the new offset
 		   and try again. */